package edu.ucf.rp2;

import java.util.ArrayList;
import java.util.List;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;


public class GoogleSearch {
	
	
	private String searchUrl;
	private String searchSource;
	
	
	public GoogleSearch (String phrase) {
		searchUrl = "https://www.google.com/search?q=" + phrase.replaceAll(" ", "+");
		fetchSearchSource();
	}
	
	/**
	 * Retrieves the source code of a SERP
	 */
	private void fetchSearchSource () {
		WebFetcher wb = new WebFetcher(searchUrl);
		wb.exec();
		searchSource = wb.getSource();
	}
	
	/**
	 * Returns a list of all ads in a SERP
	 * @return list of all ads in a SERP
	 */
	public List<GoogleAd> ads () {
		List<GoogleAd> ads = new ArrayList<GoogleAd>();
		
		Elements rawAds = adsHTML();
		
		for (Element rawAd : rawAds)
		{
			String googleURL = rawAd.attr("href");
			GoogleAd googleAd = new GoogleAd(googleURL);
			ads.add(googleAd);
		}
		
		return ads;
	}
	
	/**
	 * Returns the SERP source code
	 * @return SERP source code
	 */
	public String getSearchSource () {
		return searchSource;
	}
	
	/**
	 * Extracts the ad HTML elements from the search source
	 * @return ad HTML elements
	 */
	private Elements adsHTML () {
		Elements googleElements = new Elements();
		
		Document document = Jsoup.parse(searchSource);
		Elements anchors = document.getElementsByTag("a");
		
		for (Element anchor : anchors)
		{
			if (anchor.attr("href").indexOf("adurl=")!=-1) {
				googleElements.add(anchor);
			}
		}
		
		return googleElements;
	}	
}
